@@ -20,7 +20,6 @@ from web import sqlquote
 import sqlalchemy
 from sqlalchemy import create_engine
 from sqlalchemy.engine import Engine
-from sqlalchemy.engine.cursor import CursorResult
 
 # Default SQLAlchemy version: 1.4.x.
 __sqlalchemy_version = 1
@@ -311,7 +310,7 @@ def create_db_engine(db_name):
         return None
 
 
-def execute_sql(engine: Engine, sql: str, params=None) -> CursorResult:
+def execute_sql(engine: Engine, sql: str, params=None):
     """Execute SQL query with given db engine, supports both SQLAlchemy 1.4.x and 2.0.x."""
     if __sqlalchemy_version == 2:
         sql = text(sql)
